This function reads all available data access groups from
REDCap an returns them as a tibble::tibble().
Usage
redcap_dag_read(
redcap_uri,
token,
http_response_encoding = "UTF-8",
locale = readr::default_locale(),
verbose = TRUE,
config_options = NULL,
handle_httr = NULL
)Arguments
- redcap_uri
The uri/url of the REDCap server typically formatted as "https://server.org/apps/redcap/api/". Required.
- token
The user-specific string that serves as the password for a project. Required.
- http_response_encoding
The encoding value passed to
httr::content(). Defaults to 'UTF-8'.- locale
a
readr::locale()object to specify preferences like number, date, and time formats. This object is passed toreadr::read_csv(). Defaults toreadr::default_locale().- verbose
A boolean value indicating if
messages should be printed to the R console during the operation. The verbose output might contain sensitive information (e.g. PHI), so turn this off if the output might be visible somewhere public. Optional.- config_options
A list of options passed to
httr::POST(). See details athttr::httr_options(). Optional.- handle_httr
The value passed to the
handleparameter ofhttr::POST(). This is useful for only unconventional authentication approaches. It should beNULLfor most institutions. Optional.
Value
Currently, a list is returned with the following elements:
data: Atibble::tibble()of all data access groups of the project.success: A boolean value indicating if the operation was apparently successful.status_codes: A collection of http status codes, separated by semicolons. There is one code for each batch attempted.outcome_messages: A collection of human readable strings indicating the operations' semicolons. There is one code for each batch attempted. In an unsuccessful operation, it should contain diagnostic information.elapsed_seconds: The duration of the function.
References
The official documentation can be found on the 'API Help Page' and 'API Examples' pages on the REDCap wiki (i.e., https://redcap.vumc.org/community/post.php?id=456 and https://redcap.vumc.org/community/post.php?id=462 ). If you do not have an account for the wiki, please ask your campus REDCap administrator to send you the static material.