Enumerate the instruments to event mappings
Source:R/redcap-event-instruments.R
redcap_event_instruments.RdExport the instrument-event mappings for a project (i.e., how the data collection instruments are designated for certain events in a longitudinal project). (Copied from "Export Instrument-Event Mappings" method of REDCap API documentation, v.10.5.1)
Usage
redcap_event_instruments(
redcap_uri,
token,
arms = NULL,
delimiter = ",",
verbose = TRUE,
config_options = NULL,
handle_httr = NULL
)Arguments
- redcap_uri
The uri/url of the REDCap server typically formatted as "https://server.org/apps/redcap/api/". Required.
- token
The user-specific string that serves as the password for a project. Required.
- arms
A character string of arms to retrieve. Defaults to all arms of the project.
- delimiter
A single-character value passed to the
delimparameter ofreadr::read_delim(). Options include:,(a comma, the default),;(a semi-colon),|(a pipe),^(a caret), or\t(a tab).
- verbose
A boolean value indicating if
messages should be printed to the R console during the operation. The verbose output might contain sensitive information (e.g. PHI), so turn this off if the output might be visible somewhere public. Optional.- config_options
A list of options passed to
httr::POST(). See details athttr::httr_options(). Optional.- handle_httr
The value passed to the
handleparameter ofhttr::POST(). This is useful for only unconventional authentication approaches. It should beNULLfor most institutions. Optional.
Value
Currently, a list is returned with the following elements,
data: Atibble::tibble()where each row represents one column in the REDCap dataset.success: A boolean value indicating if the operation was apparently successful.status_code: The http status code of the operation.outcome_message: A human readable string indicating the operation's outcome.elapsed_seconds: The duration of the function.raw_text: If an operation is NOT successful, the text returned by REDCap. If an operation is successful, theraw_textis returned as an empty string to save RAM.
References
The official documentation can be found on the 'API Help Page' and 'API Examples' pages on the REDCap wiki (i.e., https://redcap.vumc.org/community/post.php?id=456 and https://redcap.vumc.org/community/post.php?id=462 ). If you do not have an account for the wiki, please ask your campus REDCap administrator to send you the static material.
Examples
if (FALSE) { # \dontrun{
uri <- "https://redcap-dev-2.ouhsc.edu/redcap/api/"
# Longitudinal project with one arm
token_1 <- "76B4A71A0158BD34C98F10DA72D5F27C" # "arm-single-longitudinal" test project
REDCapR::redcap_arm_export(redcap_uri=uri, token=token_1)$data
REDCapR::redcap_event_instruments(redcap_uri=uri, token=token_1)$data
# Project with two arms
token_2 <- "DA6F2BB23146BD5A7EA3408C1A44A556" # "longitudinal" test project
REDCapR::redcap_arm_export(redcap_uri=uri, token=token_2)$data
REDCapR::redcap_event_instruments(redcap_uri=uri, token=token_2)$data
REDCapR::redcap_event_instruments(redcap_uri=uri, token=token_2, arms = c("1", "2"))$data
REDCapR::redcap_event_instruments(redcap_uri=uri, token=token_2, arms = "2")$data
# Classic project (without arms) throws an error
token_3 <- "9A068C425B1341D69E83064A2D273A70" # "simple" test project
REDCapR::redcap_arm_export(redcap_uri=uri, token=token_3)$data
# REDCapR::redcap_event_instruments(redcap_uri=uri, token=token_3)$data
} # }