List users authorized for a project.
Usage
redcap_users_export(
redcap_uri,
token,
verbose = TRUE,
config_options = NULL,
handle_httr = NULL
)Arguments
- redcap_uri
The uri/url of the REDCap server typically formatted as "https://server.org/apps/redcap/api/". Required.
- token
The user-specific string that serves as the password for a project. Required.
- verbose
A boolean value indicating if
messages should be printed to the R console during the operation. The verbose output might contain sensitive information (e.g. PHI), so turn this off if the output might be visible somewhere public. Optional.- config_options
A list of options passed to
httr::POST(). See details athttr::httr_options(). Optional.- handle_httr
The value passed to the
handleparameter ofhttr::POST(). This is useful for only unconventional authentication approaches. It should beNULLfor most institutions. Optional.
Value
Currently, a list is returned with the following elements:
data_user: Atibble::tibble()of all users associated with the project. One row represents one user.data_user_form: Atibble::tibble()of permissions for users and forms. One row represents a unique user-by-form combination.success: A boolean value indicating if the operation was apparently successful.status_codes: A collection of http status codes, separated by semicolons. There is one code for each batch attempted.outcome_messages: A collection of human readable strings indicating the operations' semicolons. There is one code for each batch attempted. In an unsuccessful operation, it should contain diagnostic information.elapsed_seconds: The duration of the function.