This function calls the 'exportFieldNames' function of the REDCap API.
redcap_variables(
redcap_uri,
token,
delimiter = ",",
verbose = TRUE,
config_options = NULL,
handle_httr = NULL
)Currently, a list is returned with the following elements,
data: A tibble::tibble() where each row represents one column
in the REDCap dataset.
success: A boolean value indicating if the operation was apparently
successful.
status_code: The
http status code
of the operation.
outcome_message: A human readable string indicating the operation's
outcome.
elapsed_seconds: The duration of the function.
raw_text: If an operation is NOT successful, the text returned by
REDCap. If an operation is successful, the raw_text is returned as an
empty string to save RAM.
The uri/url of the REDCap server typically formatted as "https://server.org/apps/redcap/api/". Required.
The user-specific string that serves as the password for a project. Required.
A single-character value passed to
the delim parameter of readr::read_delim().
Options include:
, (a comma, the default),
; (a semi-colon),
| (a pipe),
^ (a caret), or
\t (a tab).
A boolean value indicating if messages should be printed
to the R console during the operation. The verbose output might contain
sensitive information (e.g. PHI), so turn this off if the output might
be visible somewhere public. Optional.
A list of options passed to httr::POST().
See details at httr::httr_options(). Optional.
The value passed to the handle parameter of
httr::POST().
This is useful for only unconventional authentication approaches. It
should be NULL for most institutions. Optional.
Will Beasley
As of REDCap version 6.14.2, three variable types are not returned in this call: calculated, file, and descriptive. All variables returned are writable/uploadable.
The official documentation can be found on the 'API Help Page' and 'API Examples' pages on the REDCap wiki (i.e., https://redcap.vumc.org/community/post.php?id=456 and https://redcap.vumc.org/community/post.php?id=462 ). If you do not have an account for the wiki, please ask your campus REDCap administrator to send you the static material.
if (FALSE) {
uri <- "https://redcap-dev-2.ouhsc.edu/redcap/api/"
token <- "9A068C425B1341D69E83064A2D273A70"
ds_variable <- REDCapR::redcap_variables(redcap_uri=uri, token=token)$data
}
Run the code above in your browser using DataLab